RustoreBilling class

Constructors

RustoreBilling({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for RustoreBilling. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

available() Future<PurchaseAvailabilityResultFlutter>
confirm(String id) Future<ConfirmPurchaseResponse>
deletePurchase(String purchaseId) Future<void>
getAuthorizationStatus() Future<bool>
initialize(String id, String prefix, bool debugLogs) Future<String>
isRustoreInstalled() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
products(List<String?> ids) Future<ProductsResponse>
purchase(String id, {String? developerPayload, String? orderId}) Future<PaymentResult>
purchaseInfo(String id) Future<Purchase>
purchases() Future<PurchasesResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>